@@ -1,9 +1,10 @@
 package App::perlmv;
-BEGIN {
-  $App::perlmv::VERSION = '0.42';
+{
+  $App::perlmv::VERSION = '0.43';
 }
 # ABSTRACT: Rename files using Perl code
 
+use 5.010;
 use strict;
 use warnings;
 use Cwd qw(abs_path getcwd);
@@ -395,19 +396,28 @@ sub process_items {
 sub process_item {
     my ($self, $code, $code_is_final, $item, $items) = @_;
 
-    $App::perlmv::code::FILES =
+    local $App::perlmv::code::FILES =
         [map {ref($_) ? $_->{name_for_script} : $_} @$items];
     local $_ = $item->{name_for_script};
-    my $old = $item->{real_name};
-    $self->run_code($code);
-    my $new = $_;
 
+    my $old = $item->{real_name};
     my $aold = abs_path($old);
     #die "Invalid path $old" unless defined($aold);
     $aold = "" if !defined($aold);
+    my ($oldvol,$olddir,$oldfile)=File::Spec->splitpath($aold);
+    my ($olddirvol,$olddirdir,$olddirfile) = File::Spec->splitpath(
+        abs_path($olddir));
+    local $App::perlmv::code::DIR    = $olddir;
+    local $App::perlmv::code::FILE   = $oldfile;
+    local $App::perlmv::code::PARENT = $olddirfile;
+
+    $self->run_code($code);
+
+    my $new = $_;
     my $anew = abs_path($new);
     #die "Invalid path $new" unless defined($anew);
     $anew = "" if !defined($anew);
+
     $self->{_exists}{$aold}++ if (-e $aold);
     return if $aold eq $anew;
 
@@ -537,7 +547,7 @@ App::perlmv - Rename files using Perl code
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -556,7 +566,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
