@@ -1,7 +1,12 @@
 package App::perlmv::scriptlets::std;
-BEGIN {
-  $App::perlmv::scriptlets::std::VERSION = '0.42';
+{
+  $App::perlmv::scriptlets::std::VERSION = '0.43';
 }
+
+use 5.010;
+use strict;
+use warnings;
+
 # ABSTRACT: A collection of perlmv scriptlets
 
 
@@ -128,7 +133,7 @@ App::perlmv::scriptlets::std - A collection of perlmv scriptlets
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SCRIPTLETS
 
@@ -207,7 +212,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
